@@ -7,13 +7,13 @@ Created on Sun Jun  7 23:15:48 2020
 import matplotlib.pyplot as plt
 import numpy as np
 import sklearn
-import ctypes
 from pandas import DataFrame
 from sklearn import metrics
 from sklearn.model_selection import validation_curve
 from sklearn.linear_model import LinearRegression
 from sklearn.linear_model import LogisticRegression
 from sklearn.ensemble import RandomForestRegressor
+from sklearn.ensemble import RandomForestClassifier
 from tkinter import filedialog
 from tkinter import Tk
 from tkinter import messagebox
@@ -32,13 +32,11 @@ def panfiles():
     reslist1=[]
     file=filedialog.askopenfilename()
     suc_label=Label(frame,text="Succesful!")
-    print(file)
     suc_label.grid(row=3)
     try:
         df2=pd.read_csv(file)
         df=df2
         df3=df2
-        print(df2)
     except FileNotFoundError:
         messagebox.showerror("Error","Please select a file")
     else:
@@ -52,8 +50,10 @@ def panfiles():
     
     
 def selection():
+    global reslist,reslist1
     inde_var.set(col1)
     reslist1=[]
+    reslist=[]
     flag=0
     seleccion = inde_enter.curselection()
     for i in seleccion:
@@ -67,20 +67,19 @@ def selection():
     de_b=Button(frame01,text=" *Select",command=pred,borderwidth="3")
     de_b.grid(row=11,column=1)
 
+
 def pred():
     global inp,oup,cate,cont
+    inp=reslist
     oup=[de_var.get()]
     cont=[]
     cate=[]
-    inp=reslist
     global inp1,num,i
     i=0
     num=len(inp)
     sel=Label(frame01,text="select type of the feature")
     sel.grid(row=12,column=0)
     select_fea()
-    print(cate)
-    print(cont)
 def select_fea():
     global num,i,val,v,cate,cont
 
@@ -100,8 +99,7 @@ def nextone():
         cate.append(inp[i])
     else:
         cont.append(inp[i])
-    
-    print(valu)
+
     i+=1
     if(i<num):
         select_fea()
@@ -164,13 +162,16 @@ def train_d():
 
             linreg()
         elif(alg=="Logistic Regression"):
-            print(alg)
         
             logreg()
         else:
-            print(alg)
-            print("#################################################")
             dtc()
+def dt():
+    global alg
+    clicked.set("Decision tree classsifier")
+def rf():
+    global alg
+    clicked.set("Random Forest")            
 def lin():
     global alg
     alg="Linear Regression"
@@ -185,14 +186,14 @@ def dtc():
     try:
         global xtrain,ytrain,xtest,ytest,labelenc,cont,cate
         from sklearn.tree import DecisionTreeClassifier
-        linr=DecisionTreeClassifier(max_depth=4)
+        if(alg=="Random Forest"):
+            linr=RandomForestClassifier()
+        else:
+            linr=DecisionTreeClassifier(max_depth=4)
         labelenc=LabelEncoder()
-        print(cate)
         for i in cate:
-            print(i)
             labelenc.fit(df[i])
             df[i]=labelenc.transform(df[i])
-            print(df[i])
         x=cont
         cont=tuple(cont)
         x.extend(cate)
@@ -235,7 +236,6 @@ def stat2():
         mean.grid(row=i+10,column=1)
     index=i+11
     ypr=linr.predict(xtrain)
-    print(ytrain,ypr)
     f_sco=metrics.precision_recall_fscore_support(ytrain,linr.predict(xtrain),average="weighted")
     pres=Label(frame2,text="* precison ::  "+" * "+str(f_sco[0]))
     pres.grid(row=2,column=1)
@@ -265,18 +265,31 @@ def view_tree():
     import graphviz
 
     
+    if(alg=="Random Forest"):
+        view_tree2()
+            
+    else:
+        dot_file=export_graphviz(linr,feature_names=x)
+        graph=graphviz.Source(dot_file)
+        graph.render(filename="tree2",format="png",cleanup=True)
+        top=Toplevel()
+        dl=Label(top,text="Decision tree")
+        img = Image.open("tree2.png")  # PIL solution
+        img = img.resize((1500, 500), Image.ANTIALIAS) #The (250, 250) is (height, width)
+        img = ImageTk.PhotoImage(img)
+        dtc_label=Label(top, image=img )
+        dtc_label.image=img
+        dtc_label.grid(row=1,column=0)
+def view_tree2():
+    import pydotplus
+    global clf
+    import matplotlib.pyplot as plt
+    from sklearn.tree import export_graphviz
+    import graphviz
+    
+    
+    
     
-    dot_file=export_graphviz(linr,feature_names=x)
-    graph=graphviz.Source(dot_file)
-    graph.render(filename="tree2",format="png",cleanup=True)
-    top=Toplevel()
-    dl=Label(top,text="Decision tree")
-    img = Image.open("tree2.png")  # PIL solution
-    img = img.resize((1500, 500), Image.ANTIALIAS) #The (250, 250) is (height, width)
-    img = ImageTk.PhotoImage(img)
-    dtc_label=Label(top, image=img )
-    dtc_label.image=img
-    dtc_label.grid(row=1,column=0)
     
     
     
@@ -340,7 +353,6 @@ def test_but_dtc():
     global cnf_matrix
     
     cnf_matrix=metrics.confusion_matrix(ytest,linr.predict(xtest))
-    print(cnf_matrix)
     cnf_button=Button(frame3,text="Click here to view confusion matrix",command=view_conf,borderwidth="3")
     cnf_button.grid(row=5)
 
@@ -353,11 +365,25 @@ def test_but_dtc():
     plots.grid(row=index,column=0,pady=10)
     global charts,plot_var,df1
     charts=["line plot","Bar","histplot","precision_recall"]
+    plot_var=StringVar()
+  #  plot_var().set(charts)
+    plt_box=OptionMenu(frame3,plot_var,*charts)
+    plt_box.grid(row=index+1)
+    k=x
+    df1=df.head(100)
+    k.append(y[0])
+    x.pop(-1)
+    global data1
+    data1=DataFrame(df1[k])
+    click_sub=Button(frame3,text="View",borderwidth="3",width="10",font="5",command=submit)
+    click_sub.grid(row=index+2)
     back_2=Button(frame3,text="Back",font="5",width="10",borderwidth="3",command=sub)
     back_2.grid(row=0,column=4)
     option_b=Label(frame3,text="Enter your predictors",font="5")
     option_b.grid(row=4,column=2)
     global cont_fea
+    print(cont)
+    print(cate)
     cont_fea=[]
     prediction_button2()
 def prediction_button2():
@@ -372,8 +398,6 @@ def prediction_button2():
     fun=prediction10()
 def prediction10():
     global ind,xl,eg,lg
-    print(cont)
-    print(cate)
     lg=Label(frame3,text=cont[ind],font="5")
     lg.grid(row=5,column=1)
     global eg
@@ -386,9 +410,7 @@ def dirs01():
     global ind
     global fea
     fea.append(float(x_val.get()))
-    print(fea)
     if(ind<len(cont)-1):
-        print(ind)
         flag=1
         eg.destroy()
         x_val.set("")
@@ -402,18 +424,22 @@ def dirs01():
             global lg
             lg.destroy()
             ind=0
-            prediction01()
+            prediction11()
+        else:
+            global subm
+            subm=Button(frame3,text="View Result",command=view_res01)
+            subm.grid(row=6,column=2)
+
     
-def prediction01():
+    
+def prediction11():
     global eg,lb
     global ind,sel_var,df3
     lb=Label(frame3,text=cate[ind],font="5")
     lb.grid(row=5,column=1)
     global cate_data
-    print(cate_data)
     sel_var=StringVar()
     l=cate_data[cate[ind]].unique()
-    print(cate_data)
     eg=OptionMenu(frame3,sel_var,*l)
     eg.grid(row=5,column=2)
     b=Button(frame3,text="click",command=dirs02)
@@ -422,9 +448,7 @@ def dirs02():
     global ind
     global cont_fea
     cont_fea.append(sel_var.get())
-    print(cont_fea)
     if(ind<len(cate)-1):
-        print(ind)
         flag=1
         global lb
         eg.destroy()
@@ -455,7 +479,6 @@ def view_res01():
     
     re=linr.predict(r)
     global result_lab,bac
-    print(re)
     result_lab=Label(frame3,text="Result is "+str(re[0]),font="5")
     subm.destroy()
     result_lab.grid(row=6,column=2)
@@ -470,7 +493,6 @@ def clear01():
     bac.destroy()
     eg.destroy()
     result_lab.destroy()
-    print("###################################################")
     prediction_button2()
     
     
@@ -493,7 +515,7 @@ def test_but_log():
     st7.grid(row=4,column=0)
     global cnf_matrix
     cnf_matrix=metrics.confusion_matrix(ytest,linr.predict(xtest))
-    print(cnf_matrix)
+
     cnf_button=Button(frame3,text="Click here to view confusion matrix",command=view_conf,borderwidth="3")
     cnf_button.grid(row=5)
     c=[]
@@ -547,9 +569,7 @@ def dirs1():
     global ind
     global fea
     fea.append(float(x_val.get()))
-    print(fea)
     if(ind<len(x)-2):
-        print(ind)
         flag=1
         x_val.set("")
         
@@ -564,7 +584,6 @@ def view_res1():
     r=[fea]
     re=linr.predict(r)
     global result_lab,bac
-    print(re)
     result_lab=Label(frame3,text="Result is "+str(re[0]),font="5")
     subm.destroy()
     result_lab.grid(row=6,column=2)
@@ -646,9 +665,7 @@ def dirs():
     global ind
     global fea
     fea.append(float(x_val.get()))
-    print(fea)
     if(ind<len(x)-2):
-        print(ind)
         flag=1
         x_val.set("")
         
@@ -712,7 +729,6 @@ def stat1():
     cnf_matrix=metrics.confusion_matrix(ytrain,linr.predict(xtrain))
    
 # plt.figure(figsize=(10,7))
-    print(cnf_matrix)
     c=[]
     cnf_button=Button(frame2,text="Click here to view the confusion matrix",command=view_conf,borderwidth="3")
     cnf_button.grid(row=8,column=0)
@@ -727,7 +743,6 @@ def stat1():
         mean.grid(row=i+10,column=1)
     index=i+11
     ypr=linr.predict(xtrain)
-    print(ytrain,ypr)
     f_sco=metrics.precision_recall_fscore_support(ytrain,linr.predict(xtrain),average="weighted")
     pres=Label(frame2,text="* precison ::  "+" * "+str(f_sco[0]))
     pres.grid(row=2,column=1)
@@ -735,18 +750,15 @@ def stat1():
     recall.grid(row=3,column=1)
     fscore=Label(frame2,text="* Fscore ::"+" * "+str(f_sco[2]))
     fscore.grid(row=4,column=1)
-    print(f_sco)
     gradients=linr.coef_
     global unique
     global uv
     uniq=df[y].nunique()
     uv=list(uniq)
-    print(gradients)
     grade=[]
     for i in range(len(gradients)):
         grade.append(list(gradients[i]))
     grade=np.array(grade)
-    print(grade)
     grad=Label(frame2,text=" * gradients/coef :: "+" * "+str(grade))
     grad.grid(row=index+1,column=0)
     inter=Label(frame2,text=" * Intercept :: "+" * "+str(linr.intercept_))
@@ -757,21 +769,22 @@ def stat1():
     test_l=Label(frame2,text="Click here to validate/test the data")
     test_l.grid(row=index+3)
 def view_conf():
-    import seaborn as sn
-    import matplotlib.pyplot as plt
-    global cnf_matrix
-    df_cm = pd.DataFrame(cnf_matrix, range(len(cnf_matrix)), range(len(cnf_matrix)))
-    from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
+    if(alg!="Random Forest"):
+        import seaborn as sn
+        import matplotlib.pyplot as plt
+        global cnf_matrix
+        df_cm = pd.DataFrame(cnf_matrix, range(len(cnf_matrix)), range(len(cnf_matrix)))
+        from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
     
-    figure = plt.Figure(figsize=(6,5), dpi=100)
-    ax = figure.add_subplot(111)
-    top=Toplevel()
-    chart_type = FigureCanvasTkAgg(figure,top)
-    chart_type.get_tk_widget().grid(row=8)
+        figure = plt.Figure(figsize=(6,5), dpi=100)
+        ax = figure.add_subplot(111)
+        top=Toplevel()
+        chart_type = FigureCanvasTkAgg(figure,top)
+        chart_type.get_tk_widget().grid(row=8)
 # plt.figure(figsize=(10,7))
-    sn.set(font_scale=1.4) # for label size
-    
-    sn.heatmap(df_cm, annot=True, annot_kws={"size": 16},ax=ax)    
+        sn.set(font_scale=1.4) # for label size
+        
+        sn.heatmap(df_cm, annot=True, annot_kws={"size": 16},ax=ax,cmap= 'RdBu_r') 
     
 def stat():
     global y1
@@ -812,7 +825,6 @@ def stat():
     global uv
     uniq=df[y].nunique()
     uv=list(uniq)
-    print(gradients)
     grad=Label(frame2,text=" * gradients/coef :: "+" * "+str((linr.coef_)))
     grad.grid(row=index+1,column=0)
     inter=Label(frame2,text=" * Intercept :: "+" * "+str(linr.intercept_))
@@ -823,7 +835,6 @@ def stat():
     test_l.grid(row=index+3)
 
 def submit():
-    print(plot_var.get())
     import tkinter as tk
     from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
     chart_type=plot_var.get()
@@ -904,7 +915,7 @@ def main():
     root.title("ML Prediction and Data Visualization")
     main_frame=LabelFrame(root ,borderwidth=6 ,text="Greenviz",font="25", padx=10 , pady=5,width=1000,height=1000)
     main_frame.grid(padx=200,pady=20)
-    frame=LabelFrame(main_frame ,text="Upload",borderwidth="3",font="25", padx=94 , pady=5,width=10000,height=1000)
+    frame=LabelFrame(main_frame ,text="Upload",borderwidth="3",font="25", padx=44 , pady=5,width=10000,height=1000)
     frame.grid(padx=10)
 
     upload_label=Label(frame , text=" * Upload your file *(.csv , .xlsx)",height="1",font="5")
@@ -918,9 +929,9 @@ def main():
     select_label=Label(frame , text="*  Select your algorithm")
     select_label.grid(row=4 , column=0)
     clicked.set("*   Select algorithm     *")
-    enter_alg=OptionMenu(frame , clicked , "Linear Regression" , "Logistic Regression","Desicion Tree classifier")
+    enter_alg=OptionMenu(frame , clicked , "Linear Regression" , "Logistic Regression","Desicion Tree classifier","Random Forest")
     enter_alg.grid(row=4, column=1)
-    frame01=LabelFrame(main_frame ,borderwidth="3",text="Feature Selection",font="25", padx=133, pady=5,width=1000,height=1000)
+    frame01=LabelFrame(main_frame ,borderwidth="3",text="Feature Selection",font="25", padx=85, pady=5,width=1000,height=1000)
     frame01.grid(padx=10)
 
     space_label1=Label(frame01 , text="                                                                                   ")
@@ -943,7 +954,7 @@ def main():
     de_enter.grid(row=10, column=1)
     space_label=Label(frame , text="                                                                            ")
     space_label.grid(row=10)
-    frame02=LabelFrame(main_frame,text="Train and Test",borderwidth="3",font="25", padx=108,pady="8" ,width=1000,height=1000)
+    frame02=LabelFrame(main_frame,text="Train and Test",borderwidth="3",font="25", padx=58,pady="8" ,width=1000,height=1000)
     frame02.grid(padx=10)
 
     percent_label=Label(frame02 , text="* Enter your train and test percentage Below::")
@@ -971,9 +982,7 @@ def main():
 def reset():
     messagebox.showinfo("Forgot Password" , "A reset Password link will be sent to your mail")
     
-def succregister():
-    messagebox.showinfo("Successful!" , "Successfully Registered ,Go to login page and continue")
-    login()
+
 def passcom():
     pass
 def register():
@@ -986,37 +995,37 @@ def register():
     global my_label , space_label , name_label , name_entry , space_label1 , reg_label , reg_entry , space_label2 , mail_label , mail_entry , space_label3 , branch_label , branch_entry , space_label4 , pass_label , pass_entry , space_label5 , forgot_button 
     frame02=LabelFrame(root, text="REGISTER"  , padx=100 , pady=100 , font=("helvetica" , 26))
     frame02.grid(padx=300 , pady=40)
-
+    global name,password,email,registration
     space_label=Label(frame02, text="                                                     ")
     space_label.grid(row=1)
 
     name_label=Label(frame02, text="*NAME       ::" , font=("helvetica" , 20))
     name_label.grid(row=2 ,column=0)
-
-
-    name_entry=Entry(frame02, width=40 , borderwidth=3)
+    
+    name=StringVar()
+    name_entry=Entry(frame02, width=40 , borderwidth=3,textvariable=name)
     name_entry.insert(0 ,"Enter your name..." )
     name_entry.grid(row=2 ,column=2)
-
+    
     space_label1=Label(frame02, text="                                                     ")
     space_label1.grid(row=3)
-
+    
 
     reg_label=Label(frame02 , text="*REGISTER NUMBER      ::" , font=("helvetica" , 20))
     reg_label.grid(row=4 , column=0)
-
-    reg_entry=Entry(frame02 , width=40 ,borderwidth=3)
+    registration=StringVar()
+    reg_entry=Entry(frame02 , width=40 ,borderwidth=3,textvariable=registration)
     reg_entry.insert(0 , "Enter your Register number..")
     reg_entry.grid(row=4 , column=2)
 
     space_label2=Label(frame02, text="                                                     ")
     space_label2.grid(row=5)
-
+    email=StringVar()
     mail_label=Label(frame02 , text="*MAIL.ID      ::" , font=("helvetica" , 20))
     mail_label.grid(row=6 , column=0)
-
-
-    mail_entry=Entry(frame02 , width=40 ,borderwidth=3)
+    
+    
+    mail_entry=Entry(frame02 , width=40 ,borderwidth=3,textvariable=email)
     mail_entry.insert(0 , "ex: someone@gmail.com")
     mail_entry.grid(row=6 , column=2)
 
@@ -1033,11 +1042,11 @@ def register():
 
     space_label4=Label(frame02, text="                                                     ")
     space_label4.grid(row=9)
-
+    password=StringVar()
     pass_label=Label(frame02 , text="*PASSWORD    ::" , font=("helvetica" , 20))
     pass_label.grid(row=10 , column=0)
 
-    pass_entry=Entry(frame02 , width=40 ,borderwidth=3)
+    pass_entry=Entry(frame02 , width=40 ,borderwidth=3,show="*",textvariable=password)
     pass_entry.insert(0 , "enter your password...")
     pass_entry.grid(row=10 , column=2)
 
@@ -1086,8 +1095,9 @@ def login():
 
     reg_label=Label(frame03 , text="*REGISTER NUMBER      ::" , font=("helvetica" , 20))
     reg_label.grid(row=4 , column=0)
-
-    reg_entry=Entry(frame03 , width=40 ,borderwidth=3,font="15")
+    global reg,passw
+    reg=StringVar()
+    reg_entry=Entry(frame03 , width=40 ,borderwidth=3,font="15",textvariable=reg)
     reg_entry.insert(0 , "Enter your Register number..")
     reg_entry.grid(row=4 , column=2)
 
@@ -1104,8 +1114,8 @@ def login():
 
     pass_label=Label(frame03 , text="*PASSWORD    ::" ,font=("helvetica" , 20))
     pass_label.grid(row=10 , column=0)
-
-    pass_entry=Entry(frame03 , width=40 ,borderwidth=3,font="15")
+    passw=StringVar()
+    pass_entry=Entry(frame03 , width=40 ,borderwidth=3,show="*",font="15",textvariable=passw)
     pass_entry.insert(0 , "enter your password...")
     pass_entry.grid(row=10 , column=2)
 
@@ -1123,16 +1133,34 @@ def login():
     forgot_button.grid(row=14 , column=1)
 
     for_button=Button(frame03 , text="Login",width="15",font="10",command=val_log)
-    print(k)
+
     for_button.grid(row=14 , column=2)
     about_button=Button(frame03,text="Back to Home Page",command=about,width="15",font="5",borderwidth="3")
     about_button.grid(row=14,column=4)
 def val_log():
     global k
+    messagebox.showinfo("Loading....","this may take a while\nplease wait...")
+    vreg=reg.get()
+    vpass=passw.get()
     k=1
-    if(k==1):
-        print(k)
-        main()
+    print(vreg)
+    try:
+        reqrec=db.greenviz.find_one({"register":vreg})
+    except:
+        messagebox.showerror("Error","Please check your network connection")
+        root.destroy()
+    else:
+        if(reqrec!=None):
+            if(reqrec["password"]==vpass):
+                messagebox.showinfo("Succesfull","Login succesfull")
+                main()
+            else:
+                messagebox.showerror("Error","Invalid username or password")
+        else:
+            messagebox.showerror("Error","Invalid username or password")
+
+        
+
     
 
 def dest():
@@ -1255,14 +1283,36 @@ global ydes
 ydes=[]
 ydes.append(my_menu)
 ydes.append(k)
-print(ydes)
 root.config(menu=my_menu)
 def reset():
     messagebox.showinfo("Forgot Password" , "A reset Password link will be sent to your mail")
     
 def succregister():
-    messagebox.showinfo("Successful!" , "Successfully Registered ,Go to login page and continue")
-
+    k=1
+    rname,rpassword,remail,rno=name.get(),password.get(),email.get(),registration.get()
+    try:
+        messagebox.showinfo("Loading...","This May take a while\nplease wait...")
+        
+        record={
+            "name":rname,
+            "register":rno,
+            "email":remail,
+            "password":rpassword
+            }
+        doc=db.greenviz.find_one({"register":rno})
+        if(doc==None):
+            print(doc)
+            
+            db.greenviz.insert_one(record)
+            messagebox.showinfo("Succesfull","you have succesfully registered")
+            login()
+        else:
+            messagebox.showwarning("ALert","The given registration number already exists\nPlease login")
+            login()
+    except:
+        messagebox.showerror("Error",'Please check your ntwork connection')
+        register()
+        
 
 def pdfa():
     if(k!=1):
@@ -1361,13 +1411,37 @@ def n6():
     
 
 
+
+
+
+
+
+
+
+    
+
+
+
+
+try:
+    import pymongo
+    from pymongo import MongoClient
+    client=MongoClient("mongodb+srv://shiridikumar:2002meshiridi@cluster0.qozki.mongodb.net/cluster0?retryWrites=true&w=majority")
+    db=client.cluster0
+    print("connected")
+except:
+    messagebox.showerror("Error","Please check your network connection")
+    root.destroy()
+
+
+
 file_menu=Menu(my_menu)
 my_menu.add_cascade(label="File" , menu=file_menu)
 file_menu.add_command(label="Home",command=about)
 file_menu.add_command(label="Login to your Account" , command=login)
 file_menu.add_command(label="Register" , command=register)
 file_menu.add_separator()
-file_menu.add_command(label="Exit" , command=root.quit())
+file_menu.add_command(label="Exit" , command=root.destroy)
 
 
 
@@ -1457,16 +1531,15 @@ quiz_menu.add_command(label="QUIZ 5" , command=passcom)
 
 lab_menu=Menu(my_menu)
 my_menu.add_cascade(label="V lab" , menu=lab_menu)
-lab_menu.add_command(label="Linear Regression" , command=lin1)
-lab_menu.add_command(label="Logistic Regression" , command=log1)
-lab_menu.add_command(label="Random Forest" , command=passcom)
-lab_menu.add_command(label="K means clustering" , command=passcom)
+lab_menu.add_command(label="Linear Regression" , command=lin)
+lab_menu.add_command(label="Logistic Regression" , command=log)
+lab_menu.add_command(label="Random Forest" , command=rf)
+lab_menu.add_command(label="K means clustering" , command=dt)
 
 
 
 
-if __name__.endswith('__main__'):
 
-    root.mainloop()
+root.mainloop()
     
 
